@@ -16,8 +16,8 @@
 
 import contextlib
 import itertools
+from unittest import mock
 
-import mock
 from oslotest import base as oslo_test_base
 import sqlalchemy as sqla
 from sqlalchemy.engine import url as sqla_url
@@ -386,8 +386,16 @@ class TestNonExistentDatabase(
         super(TestNonExistentDatabase, self).setUp()
 
         url = sqla_url.make_url(str(self.engine.url))
-        url.database = 'non_existent_database'
-        self.url = url
+
+        # TODO(zzzeek): remove hasattr() conditional in favor of "url.set()"
+        # when SQLAlchemy 1.4 is the minimum version in requirements
+        if hasattr(url, "set"):
+            self.url = url.set(database="non_existent_database")
+        else:
+            # TODO(zzzeek): remove when SQLAlchemy 1.4
+            # is the minimum version in requirements
+            url.database = 'non_existent_database'
+            self.url = url
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -663,19 +671,11 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
                     # session even though the SAVEPOINT was lost;
                     # the net result here is that one exception is thrown
                     # instead of two.  This is SQLAlchemy ticket #3680
-                    self.assertTrue(
-                        isinstance(
-                            dbe_inner.cause,
-                            exception.DBDuplicateEntry
-                        )
-                    )
+                    self.assertIsInstance(
+                        dbe_inner.cause, exception.DBDuplicateEntry)
+
         except exception.DBError as dbe_outer:
-            self.assertTrue(
-                isinstance(
-                    dbe_outer.cause,
-                    exception.DBDuplicateEntry
-                )
-            )
+            self.AssertIsInstance(dbe_outer.cause, exception.DBDuplicateEntry)
 
         # resets itself afterwards
         try:
